==> qcad-3.32.4.4-3-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg_BG">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Вертикално/хоризонтално</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Обратно</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Потребителски</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Край на</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>За субекта</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Перпендикулярно</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Тангенциален</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Център</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Среден</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Кръстовище</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Разстояние</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Невалиден</translation>
    </message>
</context>
</TS>

==> qcad-3.32.5.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg_BG">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Вертикално/хоризонтално</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Обратно</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Потребителски</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Мрежа</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Крайна точка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Върху обект</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Перпендикулярно</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Тангенциален</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Център</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Средна точка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Пресечна точка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Разстояние</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Невалиден</translation>
    </message>
</context>
</TS>
